@@ -57,7 +57,7 @@ __DATA__
 
 CREATE TABLE IF NOT EXISTS attachment (
     id           integer NOT NULL PRIMARY KEY AUTO_INCREMENT,
-    mail         integer,
+    mail         varchar(255),
     payload      text,
     filename     varchar(255),
     content_type varchar(255)
